@@ -25,12 +25,15 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py,v 1.55 2006/06/10 00:54:47 wwalker Exp $"
-__version__   = "$Revision: 1.55 $"
-__date__      = "$Date: 2006/06/10 00:54:47 $"
+__id__        = "$Id: braille.py,v 1.59 2006/07/28 11:33:32 wwalker Exp $"
+__version__   = "$Revision: 1.59 $"
+__date__      = "$Date: 2006/07/28 11:33:32 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import signal
+import threading
+
 import atspi
 import brl
 try:
@@ -279,17 +282,29 @@ class Text(Region):
         """
 
         self.accessible = accessible
-        result = util.getTextLineAtCaret(self.accessible)
-        self.caretOffset = result[1]
-        self.lineOffset = result[2]
+        [string, self.caretOffset, self.lineOffset] = \
+                 util.getTextLineAtCaret(self.accessible)
+
+        # Sometimes, gnome-terminal will give us very odd values when
+        # the user is editing using 'vi' and has positioned the caret
+        # at the first character of the first line.  In this case, we
+        # end up getting a very large negative number for the line offset.
+        # So, we just assume the user is at the first character.
+        #
+        if self.lineOffset < 0:
+            self.caretOffset = 0
+            self.lineOffset = 0
+            [string, startOffset, endOffset] = \
+                self.accessible.text.getTextAtOffset(
+                    0,
+                    atspi.Accessibility.TEXT_BOUNDARY_LINE_START)
+
         cursorOffset = self.caretOffset - self.lineOffset
 
         self.label = label
         if self.label:
-            string = self.label + " " + result[0]
+            string = self.label + " " + string
             cursorOffset += len(self.label) + 1
-        else:
-            string = result[0]
 
         Region.__init__(self, string, cursorOffset)
 
@@ -777,24 +792,33 @@ def _processBrailleEvent(command):
     elif command & BRL_FLG_REPEAT_DELAY:
         return True
 
+    consumed = False
+
+    if settings.timeoutCallback and (settings.timeoutTime > 0):
+        signal.signal(signal.SIGALRM, settings.timeoutCallback)
+        signal.alarm(settings.timeoutTime)
+
     if _callback:
         try:
             # Like key event handlers, a return value of True means
             # the command was consumed.
             #
-            if _callback(command):
-                return True
+            consumed = _callback(command)
         except:
-            debug.printException(debug.LEVEL_SEVERE)
+            debug.printException(debug.LEVEL_WARNING)
+            consumed = False
 
     if (command >= 0x100) and (command < (0x100 + _displaySize[0])):
         if len(_lines) > 0:
             cursor = (command - 0x100) + _viewport[0]
             lineNum = _viewport[1]
             _lines[lineNum].processCursorKey(cursor)
-            return True
+            consumed = True
 
-    return False
+    if settings.timeoutCallback and (settings.timeoutTime > 0):
+        signal.alarm(0)
+
+    return consumed
 
 def init(callback=None, tty=7):
     """Initializes the braille module, connecting to the BrlTTY driver.
