@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py,v 1.54 2006/08/01 15:26:57 wwalker Exp $"
-__version__   = "$Revision: 1.54 $"
-__date__      = "$Date: 2006/08/01 15:26:57 $"
+__id__        = "$Id: braillegenerator.py,v 1.57 2006/08/17 16:15:03 richb Exp $"
+__version__   = "$Revision: 1.57 $"
+__date__      = "$Date: 2006/08/17 16:15:03 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -461,6 +461,13 @@ class BrailleGenerator:
             regions.append(braille.Region(
                 " " + rolenames.getBrailleForRoleName(obj)))
 
+        # Things may not have gone as expected above, so we'll do some
+        # defensive programming to make sure we don't get an index out
+        # of bounds.
+        #
+        if focusedRegionIndex >= len(regions):
+            focusedRegionIndex = 0
+
         # [[[TODO: WDW - perhaps if a text area was created, we should
         # give focus to it.]]]
         #
@@ -1033,7 +1040,11 @@ class BrailleGenerator:
                     break
 
         if len(regions) == 0:
-            if settings.readTableCellRow:
+            # Adding in a check here to make sure that the parent is a
+            # valid table. It's possible that the parent could be a
+            # table cell too (see bug #351501).
+            #
+            if settings.readTableCellRow and obj.parent.table:
                 rowRegions = []
                 savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
                 settings.brailleVerbosityLevel = \
