@@ -19,12 +19,14 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py,v 1.48 2006/07/18 14:15:46 wwalker Exp $"
-__version__   = "$Revision: 1.48 $"
-__date__      = "$Date: 2006/07/18 14:15:46 $"
+__id__        = "$Id: gnomespeechfactory.py,v 1.51 2006/07/28 19:49:30 wwalker Exp $"
+__version__   = "$Revision: 1.51 $"
+__date__      = "$Date: 2006/07/28 19:49:30 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import os
+
 import gobject
 import Queue
 import string
@@ -42,7 +44,6 @@ import speechserver
 
 from acss import ACSS
 from chnames import chnames
-from punctuation_settings import punctuation
 
 from orca_i18n import _           # for gettext support
 
@@ -240,18 +241,19 @@ class SpeechServer(speechserver.SpeechServer):
 
     def __init__(self, driver, iid):
         speechserver.SpeechServer.__init__(self)
-        self.__speakers   = {}
-        self.__pitchInfo  = {}
-        self.__rateInfo   = {}
-        self.__volumeInfo = {}
-        self.__driver     = driver
-        self.__driverName = driver.driverName
-        self.__iid        = iid
-        self.__sayAll     = None
-        self.__isSpeaking = False
-        self.__eventQueue = Queue.Queue(0)
-        self.__gidleId    = 0
-        self.__gidleLock  = threading.Lock()
+        self.__speakers      = {}
+        self.__pitchInfo     = {}
+        self.__rateInfo      = {}
+        self.__volumeInfo    = {}
+        self.__driver        = driver
+        self.__driverName    = driver.driverName
+        self.__iid           = iid
+        self.__sayAll        = None
+        self.__isSpeaking    = False
+        self.__eventQueue    = Queue.Queue(0)
+        self.__gidleId       = 0
+        self.__gidleLock     = threading.Lock()
+        self.__lastResetTime = 0
 
     def __getRate(self, speaker):
         """Gets the voice-independent ACSS rate value of a voice."""
@@ -492,7 +494,8 @@ class SpeechServer(speechserver.SpeechServer):
             self.__gidleLock.acquire()
             self.__eventQueue.put((id, type, offset))
             if not self.__gidleId:
-                time.sleep(0.0001) # Attempt to sidestep GIL
+                if settings.gilSleepTime:
+                    time.sleep(settings.gilSleepTime)
                 self.__gidleId = gobject.idle_add(self.__idleHandler)
             self.__gidleLock.release()
 
@@ -606,7 +609,7 @@ class SpeechServer(speechserver.SpeechServer):
         newText = ''
         for i in range(0, len(oldText)):
             try:
-                level, action = punctuation[oldText[i]]
+                level, action = punctuation_settings.punctuation[oldText[i]]
 
                 # Special case for punctuation in text like filenames or URL's:
                 #
@@ -877,6 +880,17 @@ class SpeechServer(speechserver.SpeechServer):
     def reset(self, text=None, acss=None):
         """Resets the speech engine."""
 
+        # We might get into a vicious loop of resetting speech, so
+        # we will abort if we see this happening.
+        #
+        if (time.time() - self.__lastResetTime) < 20:
+            debug.println(debug.LEVEL_SEVERE,
+                          "Something looks wrong with speech.  Aborting.")
+            debug.printStack(debug.LEVEL_ALL)
+            os._exit(50)
+        else:
+            self.__lastResetTime = time.time()
+
         speakers = self.__speakers
         self.shutdown()
 
