@@ -21,13 +21,17 @@
 to define input events (InputEvent, KeyboardEvent, BrailleEvent,
 MouseButtonEvent, MouseMotionEvent, and SpeechEvent), and also provides a
 InputEventHandler class.  It is intended that instances of InputEventHandler
-will be used which should be used to handle all input events.
-"""
+will be used which should be used to handle all input events."""
+
+__id__        = "$Id: input_event.py,v 1.13 2006/07/28 17:33:16 wwalker Exp $"
+__version__   = "$Revision: 1.13 $"
+__date__      = "$Date: 2006/07/28 17:33:16 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
+
 import atspi
-import braille
 import debug
 import settings
-import speech
 import time
 
 KEYBOARD_EVENT     = "keyboard"
@@ -158,6 +162,10 @@ class InputEventHandler:
 
         if settings.learnModeEnabled:
             if self._description:
+                # These imports are here to eliminate circular imports.
+                #
+                import braille
+                import speech
                 braille.displayMessage(self._description)
                 speech.speak(self._description)
                 consumed = True
