@@ -18,8 +18,13 @@
 # Boston, MA 02111-1307, USA.
 
 """Provides support for defining keybindings and matching them to input
-events.
-"""
+events."""
+
+__id__        = "$Id: keybindings.py,v 1.8 2006/07/28 17:57:16 richb Exp $"
+__version__   = "$Revision: 1.8 $"
+__date__      = "$Date: 2006/07/28 17:57:16 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
 
 try:
     # This can fail due to gtk not being available.  We want to
@@ -114,6 +119,14 @@ class KeyBindings:
 
         self.keyBindings.append(keyBinding)
 
+    def remove(self, keyBinding):
+        """Removes the given KeyBinding instance from this set of keybindings.
+        """
+
+        for i in range(0, len(self.keyBindings)):
+            if keyBinding == self.keyBindings[i]:
+                del self.keyBindings[i]
+
     def getInputHandler(self, keyboardEvent):
         """Returns the input handler of the key binding that matches the
         given keycode and modifiers, or None if no match exists.
