@@ -20,9 +20,9 @@
 """Holds state that is shared among many modules.
 """
 
-__id__        = "$Id: orca_state.py,v 1.1 2006/07/28 17:33:17 wwalker Exp $"
-__version__   = "$Revision: 1.1 $"
-__date__      = "$Date: 2006/07/28 17:33:17 $"
+__id__        = "$Id: orca_state.py,v 1.2 2006/08/08 15:04:41 richb Exp $"
+__version__   = "$Revision: 1.2 $"
+__date__      = "$Date: 2006/08/08 15:04:41 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -46,7 +46,7 @@ lastInputEvent = None
 # The last timestamp from a device event. Used to set focus for the Orca
 # configuration GUI.
 #
-lastInputEventTimestamp = None
+lastInputEventTimestamp = 0
 
 # Records the last time a key was echoed.
 #
