@@ -25,10 +25,10 @@ Outloud voice parameter settings.
 
 """
 
-__id__ = "$Id: outloud.py,v 1.4 2005/11/21 16:06:04 wwalker Exp $"
+__id__ = "$Id: outloud.py,v 1.5 2006/07/31 12:41:30 wwalker Exp $"
 __author__ = "$Author: wwalker $"
-__version__ = "$Revision: 1.4 $"
-__date__ = "$Date: 2005/11/21 16:06:04 $"
+__version__ = "$Revision: 1.5 $"
+__date__ = "$Date: 2006/07/31 12:41:30 $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
 
@@ -255,10 +255,10 @@ def acss2voice(acss):
     if 'family' in acss:
         familyName = acss['family']['name']
         code += _table['family'][familyName]
-    if 'rate' in acss: code += " `vs%s" % acss['rate']
+    if 'rate' in acss: code += " `vs%s" % int(acss['rate'])
     voice = ""
     for d in ['average-pitch', 'pitch-range',
               'richness', 'stress']:
-        if d in acss:voice += _table[(familyName, d)][acss[d]]
+        if d in acss:voice += _table[(familyName, d)][int(acss[d])]
     if code or voice: code = "%s %s" % (code, voice)
     return (code, " `v1 ")
